@@ -1,5 +1,6 @@
 #from .. import Server
 from .route import Route, RouteParamType, RouteParameter
+from ..headers import Headers
 
 
 from typing import TYPE_CHECKING
@@ -9,7 +10,7 @@ if TYPE_CHECKING:
 else:
     Server = any
 
-def _handle_route(self:Server, reqpath:str, request_headers):
+def _handle_route(self:Server, reqpath:str, request_headers:Headers):
     path = tuple(int(ind) if ind.isdigit() else ind for ind in reqpath.split("?")[0].split("/"))
     route_key = Route("")
     fail = True
@@ -35,10 +36,16 @@ def _handle_route(self:Server, reqpath:str, request_headers):
         if route_parameters == {}:
             return self.routes[route_key](request_headers).generate()
         else:
-            return self.routes[route_key](request_headers, route_parameters).generate()
+            return self.routes[route_key](request_headers, **route_parameters).generate()
     except TypeError as e:
         if self.debug:
-            print(f"Route ({route_key}) has thrown a type error.\n\n  Perhapse the route's function has the wrong number of parameters.")
+            print(f"An error has occured when trying to access route ({reqpath})\n\nPerhapse you have the wrong (number of) arguments for this route.\n\nFULL ERROR:\n")
+            print(e)
         return self.error_404(reqpath)
-    except:
+    except Exception as e:
+        if self.debug:
+            print("FULL ERROR:\n")
+            print(e)
+        else:
+            print(e)
         return self.error_404(reqpath)
\ No newline at end of file
